Introducing Voice_Cloning: A Python Package for Speech Synthesis and Voice Cloning!

| Feature  | Output  |
|---|---|
| Real-time voice cloning | The package can clone a user's voice in real-time by analyzing a reference voice clip and a user's speech input |
| Speech synthesis | Allow users to generate synthetic speech using a text input with pre-loaded speakers, similar to a text-to-speech (TTS) system |
| Multi-Accent support | Supports Indian and Western-style accents for voice cloning and speech synthesis |
| Noise reduction | The package includes functionality to reduce noise in the recorded audio, improving the quality of the cloned or synthesized voice |

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install Voice-Cloning

```bash
pip install voice-cloning
```

## Usage

### Clone using an external reference voice
```python
# load all the functions
from voice_cloning.generation import *

# provide a reference sound file and a speech text
sound_path = r"xx/xxx/xxx.wav"
speech_text = "This is an awesome package!"

voice_generator(sound_path, speech_text)

# if you want to select the voice type, currently supports "indian" & "western", by default its "western"
voice_generator(sound_path, speech_text, voice_type = "western")

```
### Play and save the sound with noise reduction capabilities
```python

# play the generated sound
play_sound(generated_wav)

# save the file
save_sound(generated_wav, filename="sample output", noise_reduction=True) # enable noise reduction

```

## About
This Package is part of the Research topic "xxxxxxxx" conducted by xxxxx, xxxxxxxx. If you use this work (code, model or dataset),

Please cite us and star at: xxxxxxxxxxxxxxxxxxxxxx

## License
[MIT](https://choosealicense.com/licenses/mit/) License
